@@ -1,24 +1,22 @@
 /* eslint-disable line-comment-position, no-new-func, no-undefined */
-import os from 'os';
 
-import * as path from 'path';
+const os = require('os');
+const path = require('path');
 
-import nodeResolve from '@rollup/plugin-node-resolve';
+const { nodeResolve } = require('@rollup/plugin-node-resolve');
+const test = require('ava');
+const { getLocator } = require('locate-character');
+const { rollup } = require('rollup');
+const { install } = require('source-map-support');
 
-import test from 'ava';
-import { getLocator } from 'locate-character';
+const { testBundle } = require('../../../util/test');
 
-import { rollup } from 'rollup';
-import { install } from 'source-map-support';
+const { peerDependencies } = require('../package.json');
 
-import { testBundle } from '../../../util/test';
-import { peerDependencies } from '../package.json';
-
-import { commonjs, executeBundle, getCodeFromBundle } from './helpers/util';
+const { commonjs, executeBundle, getCodeFromBundle } = require('./helpers/util.js');
 
 install();
-
-process.chdir(__dirname);
+test.beforeEach(() => process.chdir(__dirname));
 
 const loader = (modules) => {
   return {
@@ -62,12 +60,15 @@ test('generates a sourcemap', async (t) => {
     sourcemapFile: path.resolve('bundle.js')
   });
 
-  // Hack to make it work on Node 18
+  // source-map uses the presence of fetch to detect browser environments which
+  // breaks in Node 18
+  const { fetch } = global;
   delete global.fetch;
   const { SourceMapConsumer } = await import('source-map');
   const smc = await new SourceMapConsumer(map);
-  const locator = getLocator(code, { offsetLine: 1 });
+  global.fetch = fetch;
 
+  const locator = getLocator(code, { offsetLine: 1 });
   let generatedLoc = locator('42');
   let loc = smc.originalPositionFor(generatedLoc); // 42
   t.is(loc.source, 'fixtures/samples/sourcemap/foo.js');
@@ -222,8 +223,7 @@ test.serial('handles symlinked node_modules with preserveSymlinks: false', (t) =
 
   // ensure we resolve starting from a directory with
   // symlinks in node_modules.
-
-  process.chdir('fixtures/samples/symlinked-node-modules');
+  process.chdir(path.join(__dirname, 'fixtures/samples/symlinked-node-modules'));
 
   return t.notThrowsAsync(
     rollup({
@@ -445,6 +445,15 @@ test('prefers to set name using directory for index files', async (t) => {
   t.not(code.indexOf('var nonIndex'), -1, 'contains nonIndex');
 });
 
+test('correctly wraps the default export from a CommonJS module when it is a class', async (t) => {
+  const bundle = await rollup({
+    input: 'fixtures/samples/es-module-with-class-as-default-export/main.js',
+    plugins: [commonjs()]
+  });
+  const result = await executeBundle(bundle, t);
+  t.is(result.error, undefined);
+});
+
 test('does not warn even if the ES module does not export "default"', async (t) => {
   const warns = [];
   await rollup({
